%This function calculates the whole steady state associated with our
%baseline model.

%IMPORTANT: Variables in vector out must be in the same order as in the
%dynare file baseline_model.mod. Dynare orders the variables
%alphabetically.

function out = SS2_model_baseline(params,SS0)

%beta    = params(1);              % discount factor for quarterly frequency
theta   = params(2);              % consumption coef in Cobb-Douglas utility to match L=1/3
sigma   = params(3);              % risk aversion coef
gamma   = params(4);             % elasticity of substitution between durables and nondurables is 1/(1+gamma)=1.5 from Nadinichek and 0.86 from Gomes, Kogan, and Yogo   
mu      = params(5);              % Utility share of nondurables
%alpha_n = params(6);              % labor share for nondurables
%alpha_d = params(7);              % labor share for durables
delta_k = params(8);              % .013 Engel and Wang or as in Baxter 0.071/4;  % depreciation of capital goods
delta_d = params(9);              % .05 from E&W or as in Baxter 0.156/4; % depreciation of durable goods
omega   = params(10);             % This is the parameter related to the intermediate good in durables technology: Yd=min{(1/omega)*IG;F(Kd,Ld)}, which implies IG=omega*F(Kd,Ld). 
mu_g    = params(11);
%chi     = params(12);             % risk premium parameter on debt
r_star  = params(13);

%load sol_steady ;
steady1 = SS0 ;

Ln_ss = steady1(1);       
Ld_ss = steady1(2);
Kn_ss = steady1(3);
Kd_ss = steady1(4);
Yn_ss = steady1(5);
Yd_ss = steady1(6);
N_ss  = steady1(7);
D_ss  = steady1(8);
B_ss  = steady1(9);
P_ss  = steady1(10);

Q_ss = (1+r_star)^(-1);
L_ss = Ln_ss+Ld_ss;
C_ss = (mu*N_ss^(-gamma)+(1-mu)*D_ss^(-gamma))^(-1/gamma);
Uc_ss = ((C_ss^theta*(1-L_ss)^(1-theta))^(-sigma))*(theta*C_ss^(theta-1)*(1-L_ss)^(1-theta)) ;
Ul_ss = -((C_ss^(theta)*(1-L_ss)^(1-theta))^(-sigma))*((1-theta)*C_ss^theta*(1-L_ss)^(-theta)) ;
Cn_ss = mu*N_ss^(-gamma-1)*(mu*N_ss^(-gamma)+(1-mu)*D_ss^(-gamma))^(-1/gamma-1);
Cd_ss = (1-mu)*D_ss^(-gamma-1)*(mu*N_ss^(-gamma)+(1-mu)*D_ss^(-gamma))^(-1/gamma-1);
Xkd_ss = (mu_g-1+delta_k)*Kd_ss;
Xkn_ss = (mu_g-1+delta_k)*Kn_ss;
Xd_ss = (mu_g-1+delta_d)*D_ss;
Y_ss = Yn_ss+P_ss*Yd_ss;
Ce_ss = N_ss+P_ss*Xd_ss;
NX_ss = Y_ss-Ce_ss-omega*Yd_ss-P_ss*(Xkn_ss+Xkd_ss); 
Zn_ss = 0;
Zd_ss = 0;
Zb_ss = 0;
Uc_Cn_ss = Uc_ss*Cn_ss ;
Uc_Cd_ss = Uc_ss*Cd_ss ;
lab_ss = log(L_ss);
con_ss = log(Ce_ss) ;
non_ss = log(N_ss) ;
inv_ss = log(Xkn_ss+Xkd_ss)+log(P_ss) ;
dur_ss = log(P_ss*Xd_ss) ;
nxr_ss = NX_ss/(Y_ss-omega*Yd_ss);
gdp_ss = log(Y_ss-omega*Yd_ss) ;
gdpd_ss = log(P_ss*Yd_ss) ;
gdpn_ss = log(Yn_ss);
spr_ss = 0;


out = [B_ss	C_ss Cd_ss Ce_ss Cn_ss con_ss D_ss dur_ss log(mu_g) gdp_ss gdpd_ss gdpn_ss inv_ss Kd_ss Kn_ss L_ss lab_ss Ld_ss Ln_ss N_ss non_ss NX_ss nxr_ss P_ss Q_ss spr_ss Uc_ss Uc_Cd_ss Uc_Cn_ss Ul_ss Xd_ss Xkd_ss Xkn_ss Y_ss Yd_ss Yn_ss Zd_ss Zn_ss Zb_ss]';

return