%This function solves the main steady state equations associated with the
%baseline model (model_baseline.mod). It is used with fsolve which solves
%for the vector SS given the parameters Gbar, beta, sigma, gamma,..., omega.

function out = SS_Calib_model_baseline(X, Gbar, beta, sigma, gamma, alpha_n, alpha_d, delta_k, delta_d, omega, BYbar, Lbar, Nshare)

LNbar = X(1);
LDbar = X(2);
KNbar = X(3);
KDbar = X(4);
YNbar = X(5);
YDbar = X(6);
Nbar  = X(7);
Dbar  = X(8);
Bbar  = X(9);
Pbar  = X(10);
theta = X(11);
mu    = X(12);

m1 = theta*(1-sigma)-1;
Qbar = beta*Gbar^m1; 
Cbar=(mu*Nbar^(-gamma)+(1-mu)*Dbar^(-gamma))^(-1/gamma);
Cnbar=mu*Nbar^(-gamma-1)*(mu*Nbar^(-gamma)+(1-mu)*Dbar^(-gamma))^(-1/gamma-1);


EE1 = YNbar-Nbar-omega*YDbar; % Resource constraint for nondurables
EE2 = Pbar*KNbar/YNbar-alpha_n*Qbar/(1-(1-delta_k)*Qbar);
EE3 = (Pbar/(Pbar-omega))*KDbar/YDbar-alpha_d*Qbar/(1-(1-delta_k)*Qbar);
EE4 = YDbar/LDbar-(1-alpha_n)/(1-alpha_d)*(YNbar/LNbar)/(Pbar-omega);
EE5 = Nbar+omega*YDbar-(YNbar+Pbar*YDbar+Pbar*(1-delta_k-Gbar)*(KDbar+KNbar)+Pbar*(1-delta_d-Gbar)*Dbar+Pbar*(1-Qbar*Gbar)*Bbar);
EE6 = (1-mu)*(Nbar/Dbar)^(1+gamma)-mu*(Pbar*(1-Qbar*(1-delta_d))/Qbar);
EE7 = LNbar*(1+(1-theta)/theta*Cbar/((1-alpha_n)*Cnbar*YNbar))-(1-LDbar);
EE8 = YNbar-(Gbar*LNbar)^(1-alpha_n)*KNbar^alpha_n;
EE9 = YDbar-(Gbar*LDbar)^(1-alpha_d)*KDbar^alpha_d;
EE10= Pbar*Bbar-BYbar*(YNbar+(Pbar-omega)*YDbar);
EE11= (LNbar+LDbar) - Lbar;
EE12= Nbar/(Nbar+Pbar*(delta_d+Gbar-1)*Dbar) - Nshare;


out = [EE1; EE2; EE3; EE4; EE5; EE6; EE7; EE8; EE9; EE10; EE11; EE12];

return
