% PROGRAM THAT SOLVES THE MODEL AND RETURNS THE UNDELYING SHOCKS 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%Preliminiaries
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
close all;
warning off all

addpath c:\dynare\4.4.3\matlab;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 0. Defining dataset:
global datafile

datafile = 'data_mex_quarterly';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. Defining some parameters (the ones relevant for Steady State computations)
parameters_baseline ;
load(datafile);
mu_g = 1 + mean(Dy(:,1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2. Solving for the steady state vector and  parameters mu and theta on SS_Calib_model_baseline:
options0=optimset('TolFun',1e-7,'Display','off','MaxIter',100000,'FunValCheck','on','MaxFunEvals',5000000);
load sol_steady ;

LB = [0 0 0 0 0 0 0 0 -inf 0 0 0];
UB = [1 1 inf inf inf inf inf inf 0 inf 1 1];

global SS1
SS1 = lsqnonlin(@(x) SS_Calib_model_baseline(x, mu_g, beta, sigma, gamma, alpha_n, alpha_d, delta_k, delta_d, omega, BYbar, Lbar, Nshare),SS0,LB,UB,options0);
SS0 = SS1; 
save sol_steady SS0;

theta = SS1(11);
mu    = SS1(12);
r_star = mu_g^(1-theta*(1-sigma))/beta - 1 ;

params1 = [beta theta sigma gamma mu alpha_n alpha_d delta_k delta_d omega mu_g chi r_star]';  %same order as in the mod files

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3. Obtaining the whole SS vector:

SS = SS2_model_baseline(params1,SS1(1:10)) ;
save steady_state SS ;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 4. Setting remaining model parameters:

% % Spec 2:
sigma_g = 1.81;
sigma_n = 1.35;
sigma_d = 1.19;
sigma_b = 0;
rho_g   = 0.12;
rho_n   = 0.79;
rho_d   = 0.69;
rho_b   = 0;
rho_nd  = 0;
psi     = 0.40;
phi     = 1.92;     
eta     = -.031;
nu      = 0;

params2 = [sigma_g sigma_n sigma_d sigma_b rho_g rho_n rho_d rho_b rho_nd psi phi eta nu];

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 5. Estimating the model by ML: (sigma_g, sigma_n, sigma_d, rho_g, rho_n,
% rho_d, eta)

save parameters params1 params2;

% Estimation 1: here we set varobs dgdp dcon dnxr
dynare model_AMT_1 noclearall

% Estimation 2: here we set varobs dgdp dnon dnxr
dynare model_AMT_2 noclearall
