//Small Open Economy Model with durable and nondurable Goods as in Alvarez-Parra, Brandao-Marques y Toledo (2013)

var B C Cd Ce Cn con D dur G gdp gdpd gdpn inv Kd Kn L lab Ld Lm N non NX nxr P Q spr Uc Uc_Cd Uc_Cn Ul Xd Xkd Xkn Y Yd Yn Zd Zn Zb dgdp dgdpd dgdpn dcon dnon ddur dinv dnxr dspr dlab;
varexo e_g e_n e_d;  // e_b ;

parameters beta theta sigma gamma mu alpha_n alpha_d delta_k delta_d omega mu_g phi psi chi rho_g rho_n rho_d rho_b r_star eta nu Bbar Ybar Pbar;

load parameters;
beta    = params1(1);              % discount factor for quarterly frequency
theta   = params1(2);              % consumption coef in Cobb-Douglas utility to match L=1/3
sigma   = params1(3);              % risk aversion coef
gamma   = params1(4);              % elasticity of substitution between durables and nondurables is 1/(1+mu_p)=1.5 from Nadinichek and 0.86 from Gomes, Kogan, and Yogo   
mu      = params1(5);              % Utility share of nondurables
alpha_n = params1(6);              % Capital income share in nondurable sector
alpha_d = params1(7);              % Capital income share in durable sector
delta_k = params1(8);              % .013 Engel and Wang or as in Baxter 0.071/4;  % depreciation of capital goods
delta_d = params1(9);              % .05 from E&W or as in Baxter 0.156/4; % depreciation of durable goods
omega   = params1(10);             % This is the parameter related to the intermediate good in durables technology: Yd=min{(1/omega)*IG;F(Kd,Ld)}, which implies IG=omega*F(Kd,Ld). 
mu_g    = params1(11);
chi     = params1(12);             % risk premium parameter on debt 
r_star  = params1(13);    

sigma_g = params2(1);
sigma_n = params2(2);
sigma_d = params2(3);
sigma_b = params2(4);
rho_g   = params2(5); 
rho_n   = params2(6);
rho_d   = params2(7);
rho_b   = params2(8);
rho_nd  = params2(9);
psi     = params2(10);
phi     = params2(11);
eta     = params2(12); 
nu      = params2(13); 

load steady_state ;
Ybar = SS(34) ;
Pbar = SS(24) ;
Bbar = Pbar*SS(1) ;

model;
    //Some auxiliary variables:
    Ul = -(1-theta)*C^(theta*(1-sigma))*(1-L)^((1-theta)*(1-sigma)-1) ;
    Uc = theta*C^(theta*(1-sigma)-1)*(1-L)^((1-theta)*(1-sigma)) ;
    Cn = (mu*N^(-gamma)+(1-mu)*D(-1)^(-gamma))^(-1-1/gamma)*mu*N^(-gamma-1) ;
    Cd = (mu*N^(-gamma)+(1-mu)*D(-1)^(-gamma))^(-1-1/gamma)*(1-mu)*D(-1)^(-gamma-1) ;
    Uc_Cn = Uc*Cn ;
    Uc_Cd = Uc*Cd ;
    C = (mu*N^(-gamma)+(1-mu)*D(-1)^(-gamma))^(-1/gamma) ;

    //Static optimality conditions:
    Ld = 1-(1+(1-theta)/theta*C/(Cn*(1-alpha_n)*Yn))*Lm;
    (1-alpha_n)*Yn/Lm = (P-omega)*(1-alpha_d)*Yd/Ld ;

    //Resource constraints:
    N + P*exp(G)*D + P*exp(G)*Kn + P*exp(G)*Kd + P*Q*exp(G)*B = Y - omega*Yd + (1-delta_k)*P*(Kn(-1)+Kd(-1)) - (phi/2)*(exp(G)*Kn/Kn(-1) - mu_g)^2*P*Kn(-1) - (phi/2)*(exp(G)*Kd/Kd(-1) - mu_g)^2*P*Kd(-1) + (1-delta_d)*P*D(-1) - (psi/2)*(exp(G)*D/D(-1) - mu_g)^2*P*D(-1) + P*B(-1) ;
    Yn = N + omega*Yd ;                        %Nondurable RC

    //Sectoral outputs:
    Yn = exp(Zn)*Kn(-1)^alpha_n*(exp(G)*Lm)^(1-alpha_n) ;
    Yd = exp(Zd)*Kd(-1)^alpha_d*(exp(G)*Ld)^(1-alpha_d) ;
    
    //Law of motions for capital and durable stocks:
    Xkn = exp(G)*Kn - (1-delta_k)*Kn(-1) + phi/2*(exp(G)*Kn/Kn(-1)-mu_g)^2*Kn(-1);
    Xkd = exp(G)*Kd - (1-delta_k)*Kd(-1) + phi/2*(exp(G)*Kd/Kd(-1)-mu_g)^2*Kd(-1);
    Xd  = exp(G)*D - (1-delta_d)*D(-1) + psi/2*(exp(G)*D/D(-1)-mu_g)^2*D(-1);

    //Some relevant variables:
    L  = Lm + Ld ;                              %Total hours
    Y  = Yn + P*Yd ;                            %Total output (not GDP)
    NX = Y - Ce - omega*Yd - P*(Xkn + Xkd) ;    %Net exports
    Ce = N + P*Xd ;                             %Total consumption expenditure

    //Euler Equations:
    Uc_Cn*P*(1+phi*(exp(G)*Kn/Kn(-1) - mu_g)) = beta*exp(G)^(theta*(1-sigma)-1)*Uc_Cn(+1)*( alpha_n*(Yn(+1)/Kn) + P(+1)*(1 - delta_k + (phi/2)*((exp(G(+1))*Kn(+1)/Kn)^2 - mu_g^2)) ) ; 
    Uc_Cn*P*(1+phi*(exp(G)*Kd/Kd(-1) - mu_g)) = beta*exp(G)^(theta*(1-sigma)-1)*Uc_Cn(+1)*(P(+1)*( alpha_d*(Yd(+1)/Kd) + 1 - delta_k + (phi/2)*((exp(G(+1))*Kd(+1)/Kd)^2 - mu_g^2) ) - omega*alpha_d*(Yd(+1)/Kd)) ; 
    Uc_Cn*P*(1+psi*(exp(G)*D/D(-1) - mu_g)) = beta*exp(G)^(theta*(1-sigma)-1) * ( Uc_Cn(+1)*P(+1)*(1 - delta_d + (psi/2)*((exp(G(+1))*D(+1)/D)^2 - mu_g^2)) + Uc_Cd(+1) ) ;
    Uc_Cn*P*Q  = beta*exp(G)^(theta*(1-sigma)-1) * P(+1)*Uc_Cn(+1) ;  

    //Boorrowing premium and bond price:
    spr  = chi*(exp(P*B-Bbar)-1) + eta*(Y(+1)-Ybar) + nu*e_g + Zb;
    Q = (1 + r_star + spr)^(-1) ;

    //Shock processes:
    Zn = rho_n*Zn(-1) + e_n/100 ; 
    Zd = rho_d*Zd(-1) + e_d/100 ;
    G = (1-rho_g)*log(mu_g) + rho_g*G(-1) + e_g/100 ;
    Zb = 0; //rho_b*Zb(-1) + e_b/100 ;
    
    //Log of variables of interest:
    gdp  = log(Yn + (Pbar-omega)*Yd) ;
    gdpd = log(Pbar*Yd) ; 
    gdpn = log(Yn);
    con  = log(N + Pbar*Xd);
    non  = log(N);
    dur  = log(Pbar*Xd); 
    inv  = log(Xkn+Xkd)+log(Pbar);
    nxr  = (Yn + (Pbar-omega)*Yd - N - Pbar*Xd - Pbar*Xkn - Pbar*Xkd)/(Yn + (Pbar-omega)*Yd) ;
    lab  = log(L);

    //First difference of variables of interest:
    dgdp = gdp - gdp(-1) + G(-1);
    dgdpn = gdpn - gdpn(-1) + G(-1);
    dgdpd = gdpd - gdpd(-1) + G(-1);
    dcon = con - con(-1) + G(-1);
    dnon = non - non(-1) + G(-1);
    ddur = dur - dur(-1) + G(-1);
    dinv = inv - inv(-1) + G(-1);
    dnxr = nxr - nxr(-1);
    dspr = 4*(spr - spr(-1));
    dlab = lab - lab(-1);

end;


initval;
B = SS(1) ;
C = SS(2) ;
Cd = SS(3) ;
Ce = SS(4) ;
Cn = SS(5) ;
con = SS(6);
D = SS(7) ;
dur = SS(8);
G = SS(9) ;
gdp = SS(10);
gdpd = SS(11); 
gdpn = SS(12);
inv = SS(13);
Kd = SS(14) ;
Kn = SS(15) ;
L = SS(16) ;
lab = SS(17) ;
Ld = SS(18);
Lm = SS(19) ;
N = SS(20) ;
non = SS(21);
NX = SS(22) ;
nxr= SS(23);
P = SS(24) ;
Q = SS(25) ;
spr = SS(26);
Uc = SS(27);
Uc_Cd = SS(28) ;
Uc_Cn = SS(29) ;
Ul = SS(30) ;
Xd = SS(31) ;
Xkd = SS(32) ;
Xkn = SS(33);
Y  = SS(34) ;
Yd = SS(35) ;
Yn = SS(36) ;
Zd = SS(37);
Zn = SS(38);
Zb = SS(39);
dgdp = log(mu_g);
dgdpd = log(mu_g);
dgdpn = log(mu_g);
dcon = log(mu_g);
dnon = log(mu_g);
ddur = log(mu_g);
dinv = log(mu_g);
dnxr = 0;
dspr = 0;
dlab = 0;
end;

steady;
check;

shocks;
var e_g = sigma_g^2 ;
var e_n = sigma_n^2 ;
var e_d = sigma_d^2 ;
//var e_b = sigma_b^2 ;
corr e_n, e_d = rho_nd ;
end;

//ML estimation with dgdp dcon dnxr

varobs dgdp dcon dnxr;

estimated_params; 
stderr e_g, , .0001, 30;
stderr e_n, , .0001, 30;
stderr e_d, , .0001, 30;
rho_g, , -.9999, .9999;
rho_n, , -.9999, .9999;
rho_d, , -.9999, .9999;
eta, , -.1, .1;
end;

estimated_params_init(use_calibration);
end;

estimation(datafile=data_estimate,mode_compute=4,nograph);  //ML estimation

global dataset_ bayestopt_
load('model_AMT_1_mode.mat');

// Calculating likelihood for different datasets:
load('Dataset_Likelihood_Mex_1.mat') // dataset 1: dgdp dcon dnxr
[lh_1,junk1,junk2,exit_flag,ys,trend_coeff,info] = dsge_likelihood(xparam1,dataset_,options_,M_,estim_params_,bayestopt_,oo_);

load('Dataset_Likelihood_Mex_2.mat') // dataset 2: dgdp dnon dnxr
[lh_2,junk1,junk2,exit_flag,ys,trend_coeff,info] = dsge_likelihood(xparam1,dataset_,options_,M_,estim_params_,bayestopt_,oo_);

likelihood_ML_1 = [lh_1,lh_2];
save Likelihood_ML_Mex likelihood_ML_1;


